@@ -65,7 +65,7 @@ body(fam1)[[nopar+2]][[2]]$G.dev.incr <- fam$G.dev.incr
   switch(nopar,  
           {
           # 1 parameter 
-      fam$dldm <- function(y,mu) as.vector(attr(gamlss:::numeric.deriv(TEST(y, mu, log=TRUE), "mu", delta=NULL), "gradient")) 
+      fam$dldm <- function(y,mu) as.vector(attr(gamlss::numeric.deriv(TEST(y, mu, log=TRUE), "mu", delta=NULL), "gradient")) 
            # mu
            sMU <- sub("TEST", dfun, body(fam$dldm))
 if (!is.na(delta[1])) sMU <- sub("NULL",  as.character(delta[1]), sMU) 
@@ -73,13 +73,13 @@ body(fam$dldm) <- parse(text=sMU[length(sMU)])
 body(fam1)[[nopar+2]][[2]]$dldm  <- fam$dldm
           # residuals
       cen <- paste("censored=", "\"", type ,sep="") # i.e.censored= "right"
-          sres <- gsub(porfun, paste(pfun,"\" ,", cen),  deparse(fam$rqres)) 
-          sres <- gsub("expression", "",  sres)
+     sres <- gsub(porfun, paste(pfun,"\" ,", cen),  deparse(fam$rqres[[1]])) 
+          #sres <- gsub("expression", "",  sres)
      fam$rqres <- parse(text=sres)
 body(fam1)[[nopar+2]][[2]]$rqres <- fam$rqres
          # initial mu
-           inimu <- gsub("y", "y[,1]",  deparse(fam$mu.initial))
-           inimu <- gsub("expression", "",  inimu)
+           inimu <- gsub("y", "y[,1]",  deparse(fam$mu.initial[[1]]))
+         #  inimu <- gsub("expression", "",  inimu)
            fam$mu.initial <- parse(text=inimu)
 body(fam1)[[nopar+2]][[2]]$mu.initial <- fam$mu.initial
           #y.valid
@@ -90,8 +90,8 @@ body(fam1)[[nopar+2]][[2]]$y.valid <- fam$y.valid
           }, 
           { 
           # 2 parameters  
-      fam$dldm <- function(y,mu,sigma) as.vector(attr(gamlss:::numeric.deriv(TEST(y, mu, sigma, log=TRUE), "mu", delta=NULL), "gradient"))
-      fam$dldd <- function(y,mu,sigma) as.vector(attr(gamlss:::numeric.deriv(TEST(y, mu, sigma, log=TRUE), "sigma", delta=NULL), "gradient"))
+      fam$dldm <- function(y,mu,sigma) as.vector(attr(gamlss::numeric.deriv(TEST(y, mu, sigma, log=TRUE), "mu", delta=NULL), "gradient"))
+      fam$dldd <- function(y,mu,sigma) as.vector(attr(gamlss::numeric.deriv(TEST(y, mu, sigma, log=TRUE), "sigma", delta=NULL), "gradient"))
           # mu 
            sMU <- sub("TEST", dfun, body(fam$dldm))
 if (!is.na(delta[1])) sMU <- sub("NULL",  as.character(delta[1]), sMU) 
@@ -121,18 +121,18 @@ if (!is.na(delta[2])) sSIGMA <- sub("NULL",  as.character(delta[2]), sSIGMA)
          #cen <- paste("censored=", "\"", type, "censored" , "\"")
          # sres <- gsub(porfun, paste(pfun,cen),  deparse(fam$rqres)) 
            cen <- paste("censored=", "\"", type ,sep="") # i.e.censored= "right"
-          sres <- gsub(porfun, paste(pfun,"\" ,", cen),  deparse(fam$rqres)) 
-          sres <- gsub("expression", "",  sres)
+          sres <- gsub(porfun, paste(pfun,"\" ,", cen),  deparse(fam$rqres[[1]])) 
+         #sres <- gsub("expression", "",  sres)
      fam$rqres <- parse(text=sres)
           body(fam1)[[nopar+2]][[2]]$rqres <- fam$rqres
           # initial mu
-           inimu <- gsub("y", "y[,1]",  deparse(fam$mu.initial))
-           inimu <- gsub("expression", "",  inimu)
+           inimu <- gsub("y", "y[,1]",  deparse(fam$mu.initial[[1]]))
+           #inimu <- gsub("expression", "",  inimu)
            fam$mu.initial <- parse(text=inimu)
            body(fam1)[[nopar+2]][[2]]$mu.initial <- fam$mu.initial
          # initial sigma
-           inisigma <- gsub("y", "y[,1]",  deparse(fam$sigma.initial))
-           inisigma <- gsub("expression", "",  inisigma)
+           inisigma <- gsub("y", "y[,1]",  deparse(fam$sigma.initial[[1]]))
+         # inisigma <- gsub("expression", "",  inisigma)
            fam$sigma.initial <- parse(text=inisigma)
            body(fam1)[[nopar+2]][[2]]$sigma.initial <- fam$sigma.initial
          #y.valid
@@ -142,9 +142,9 @@ if (!is.na(delta[2])) sSIGMA <- sub("NULL",  as.character(delta[2]), sSIGMA)
            }, 
            {
            # 3 parameters   
-      fam$dldm <- function(y,mu,sigma,nu) as.vector(attr(gamlss:::numeric.deriv(TEST(y, mu, sigma, nu, log=TRUE), "mu", delta=NULL), "gradient"))
-      fam$dldd <- function(y,mu,sigma,nu) as.vector(attr(gamlss:::numeric.deriv(TEST(y, mu, sigma, nu, log=TRUE), "sigma", delta=NULL), "gradient"))
-      fam$dldv <- function(y,mu,sigma,nu) as.vector(attr(gamlss:::numeric.deriv(TEST(y, mu, sigma, nu, log=TRUE), "nu", delta=NULL), "gradient"))
+      fam$dldm <- function(y,mu,sigma,nu) as.vector(attr(gamlss::numeric.deriv(TEST(y, mu, sigma, nu, log=TRUE), "mu", delta=NULL), "gradient"))
+      fam$dldd <- function(y,mu,sigma,nu) as.vector(attr(gamlss::numeric.deriv(TEST(y, mu, sigma, nu, log=TRUE), "sigma", delta=NULL), "gradient"))
+      fam$dldv <- function(y,mu,sigma,nu) as.vector(attr(gamlss::numeric.deriv(TEST(y, mu, sigma, nu, log=TRUE), "nu", delta=NULL), "gradient"))
            # mu
            sMU <- sub("TEST", dfun, body(fam$dldm))
 if (!is.na(delta[1]))sMU <- sub("NULL",  as.character(delta[1]), sMU)          
@@ -192,23 +192,23 @@ if (!is.na(delta[3])) sNU <- sub("NULL",  as.character(delta[3]), sNU)
           body(fam1)[[nopar+2]][[2]]$d2ldv2  <- fam$d2ldv2
            #residuals
       cen <- paste("censored=", "\"", type ,sep="") # i.e.censored= "right"
-          sres <- gsub(porfun, paste(pfun,"\" ,", cen),  deparse(fam$rqres)) 
-          sres <- gsub("expression", "",  sres)
+          sres <- gsub(porfun, paste(pfun,"\" ,", cen),  deparse(fam$rqres[[1]])) 
+         #sres <- gsub("expression", "",  sres)
      fam$rqres <- parse(text=sres) 
           body(fam1)[[nopar+2]][[2]]$rqres  <- fam$rqres
            # initial mu
-           inimu <- gsub("y", "y[,1]",  deparse(fam$mu.initial))
-           inimu <- gsub("expression", "",  inimu)
+           inimu <- gsub("y", "y[,1]",  deparse(fam$mu.initial[[1]]))
+           # inimu <- gsub("expression", "",  inimu)
            fam$mu.initial <- parse(text=inimu)
            body(fam1)[[nopar+2]][[2]]$mu.initial  <- fam$mu.initial
           # initial sigma
-           inisigma <- gsub("y", "y[,1]",  deparse(fam$sigma.initial))
-           inisigma <- gsub("expression", "",  inisigma)
+           inisigma <- gsub("y", "y[,1]",  deparse(fam$sigma.initial[[1]]))
+          # inisigma <- gsub("expression", "",  inisigma)
            fam$sigma.initial <- parse(text=inisigma)
            body(fam1)[[nopar+2]][[2]]$sigma.initial  <- fam$sigma.initial
            # initial nu
-           ininu <- gsub("y", "y[,1]",  deparse(fam$nu.initial))
-           ininu <- gsub("expression", "",  ininu)
+           ininu <- gsub("y", "y[,1]",  deparse(fam$nu.initial[[1]]))
+           #ininu <- gsub("expression", "",  ininu)
            fam$nu.initial <- parse(text=ininu)
            body(fam1)[[nopar+2]][[2]]$nu.initial  <- fam$nu.initial
           #y.valid
@@ -218,10 +218,10 @@ if (!is.na(delta[3])) sNU <- sub("NULL",  as.character(delta[3]), sNU)
            },
            {
            # 4 parameters
-      fam$dldm <- function(y,mu,sigma,nu,tau) as.vector(attr(gamlss:::numeric.deriv(TEST(y, mu, sigma, nu, tau, log=TRUE), "mu", delta=NULL), "gradient"))
-      fam$dldd <- function(y,mu,sigma,nu,tau) as.vector(attr(gamlss:::numeric.deriv(TEST(y, mu, sigma, nu, tau, log=TRUE), "sigma", delta=NULL), "gradient"))
-      fam$dldv <- function(y,mu,sigma,nu,tau) as.vector(attr(gamlss:::numeric.deriv(TEST(y, mu, sigma, nu, tau, log=TRUE), "nu", delta=NULL), "gradient"))
-      fam$dldt <- function(y,mu,sigma,nu,tau) as.vector(attr(gamlss:::numeric.deriv(TEST(y, mu, sigma, nu, tau, log=TRUE), "tau", delta=NULL), "gradient"))
+      fam$dldm <- function(y,mu,sigma,nu,tau) as.vector(attr(gamlss::numeric.deriv(TEST(y, mu, sigma, nu, tau, log=TRUE), "mu", delta=NULL), "gradient"))
+      fam$dldd <- function(y,mu,sigma,nu,tau) as.vector(attr(gamlss::numeric.deriv(TEST(y, mu, sigma, nu, tau, log=TRUE), "sigma", delta=NULL), "gradient"))
+      fam$dldv <- function(y,mu,sigma,nu,tau) as.vector(attr(gamlss::numeric.deriv(TEST(y, mu, sigma, nu, tau, log=TRUE), "nu", delta=NULL), "gradient"))
+      fam$dldt <- function(y,mu,sigma,nu,tau) as.vector(attr(gamlss::numeric.deriv(TEST(y, mu, sigma, nu, tau, log=TRUE), "tau", delta=NULL), "gradient"))
            sMU <- sub("TEST", dfun, body(fam$dldm))
 if (!is.na(delta[1])) sMU <- sub("NULL",  as.character(delta[1]), sMU)      
          body(fam$dldm) <- parse(text=sMU[length(sMU)])
@@ -290,28 +290,28 @@ if (!is.na(delta[4])) sTAU <- sub("NULL",  as.character(delta[4]), sTAU)
           body(fam1)[[nopar+2]][[2]]$d2ldt2  <- fam$d2ldt2
           # residuals 
       cen <- paste("censored=", "\"", type ,sep="") # i.e.censored= "right"
-          sres <- gsub(porfun, paste(pfun,"\" ,", cen),  deparse(fam$rqres)) 
-          sres <- gsub("expression", "",  sres)
+          sres <- gsub(porfun, paste(pfun,"\" ,", cen),  deparse(fam$rqres[[1]])) 
+        # sres <- gsub("expression", "",  sres)
      fam$rqres <- parse(text=sres)
           body(fam1)[[nopar+2]][[2]]$rqres  <- fam$rqres
            # initial mu
-           inimu <- gsub("y", "y[,1]",  deparse(fam$mu.initial))
-           inimu <- gsub("expression", "",  inimu)
+           inimu <- gsub("y", "y[,1]",  deparse(fam$mu.initial[[1]]))
+           #inimu <- gsub("expression", "",  inimu)
            fam$mu.initial <- parse(text=inimu)
            body(fam1)[[nopar+2]][[2]]$mu.initial  <- fam$mu.initial
           # initial sigma
-           inisigma <- gsub("y", "y[,1]",  deparse(fam$sigma.initial))
-           inisigma <- gsub("expression", "",  inisigma)
+           inisigma <- gsub("y", "y[,1]",  deparse(fam$sigma.initial[[1]]))
+           #inisigma <- gsub("expression", "",  inisigma)
            fam$sigma.initial <- parse(text=inisigma) 
            body(fam1)[[nopar+2]][[2]]$sigma.initial  <- fam$sigma.initial
            # initial nu
-           ininu <- gsub("y", "y[,1]",  deparse(fam$nu.initial))
-           ininu <- gsub("expression", "",  ininu)
+           ininu <- gsub("y", "y[,1]",  deparse(fam$nu.initial[[1]]))
+           #ininu <- gsub("expression", "",  ininu)
            fam$nu.initial <- parse(text=ininu)
            body(fam1)[[nopar+2]][[2]]$nu.initial  <- fam$nu.initial
           # initial tau
-           initau <- gsub("y", "y[,1]",  deparse(fam$tau.initial))
-           initau <- gsub("expression", "",  initau)
+           initau <- gsub("y", "y[,1]",  deparse(fam$tau.initial[[1]]))
+           #initau <- gsub("expression", "",  initau)
            fam$tau.initial <- parse(text=initau)
            body(fam1)[[nopar+2]][[2]]$tau.initial  <- fam$tau.initial
           #y.valid
